==> igniteui-react-18.2.2-beta.0.tgz: package/esm5/lib/ProgressBase.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { ProgressBaseVariant_$type } from "./ProgressBaseVariant";
/**
 * @hidden
 */
var ProgressBase = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ProgressBase, _super);
    function ProgressBase() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.b = new WCNativeHelper();
        _this.i = null;
        return _this;
    }
    Object.defineProperty(ProgressBase.prototype, "c", {
        get: function () {
            return this.b;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ProgressBase.prototype, "nativeElement", {
        get: function () {
            return this.i;
        },
        set: function (a) {
            this.i = a;
            this.b.n = this.i;
        },
        enumerable: false,
        configurable: true
    });
    ProgressBase.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(ProgressBase.prototype, "g", {
        get: function () {
            var ret_ = this.c.m("max");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.c.u("max", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ProgressBase.prototype, "h", {
        get: function () {
            var ret_ = this.c.m("value");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.c.u("value", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ProgressBase.prototype, "a", {
        get: function () {
            var ret_ = this.c.m("variant");
            ret_ = enumGetBox(ProgressBaseVariant_$type, EnumUtil.getEnumValue(ProgressBaseVariant_$type, this.c.f(ProgressBaseVariant_$type, ret_)));
            return EnumUtil.getEnumValue(ProgressBaseVariant_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(ProgressBaseVariant_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.c.u("variant", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ProgressBase.prototype, "f", {
        get: function () {
            var ret_ = this.c.m("animationDuration");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.c.u("animationDuration", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ProgressBase.prototype, "e", {
        get: function () {
            var ret_ = this.c.m("indeterminate");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.c.u("indeterminate", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ProgressBase.prototype, "d", {
        get: function () {
            var ret_ = this.c.m("hideLabel");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.c.u("hideLabel", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ProgressBase.prototype, "k", {
        get: function () {
            var ret_ = this.c.m("labelFormat");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.c.u("labelFormat", value_);
        },
        enumerable: false,
        configurable: true
    });
    ProgressBase.prototype.l = function () {
        this.nativeElement.connectedCallback();
    };
    ProgressBase.$t = markType(ProgressBase, 'ProgressBase', BaseElement.$);
    return ProgressBase;
}(BaseElement));
export { ProgressBase };

==> igniteui-react-18.6.1-beta.0.tgz: package/esm5/lib/ProgressBase.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { ProgressBaseVariant_$type } from "./ProgressBaseVariant";
/**
 * @hidden
 */
var ProgressBase = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ProgressBase, _super);
    function ProgressBase() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.b = new WCNativeHelper();
        _this.i = null;
        return _this;
    }
    Object.defineProperty(ProgressBase.prototype, "c", {
        get: function () {
            return this.b;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ProgressBase.prototype, "nativeElement", {
        get: function () {
            return this.i;
        },
        set: function (a) {
            this.i = a;
            this.b.o = this.i;
        },
        enumerable: false,
        configurable: true
    });
    ProgressBase.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(ProgressBase.prototype, "g", {
        get: function () {
            var ret_ = this.c.n("max");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.c.v("max", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ProgressBase.prototype, "h", {
        get: function () {
            var ret_ = this.c.n("value");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.c.v("value", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ProgressBase.prototype, "a", {
        get: function () {
            var ret_ = this.c.n("variant");
            if ((ret_ === undefined && this.___rawMode)) {
                return undefined;
            }
            ret_ = enumGetBox(ProgressBaseVariant_$type, EnumUtil.getEnumValue(ProgressBaseVariant_$type, this.c.f(ProgressBaseVariant_$type, ret_)));
            return EnumUtil.getEnumValue(ProgressBaseVariant_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(ProgressBaseVariant_$type, a);
            value_ = WCNativeHelper.camel(value_.toString());
            this.c.v("variant", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ProgressBase.prototype, "f", {
        get: function () {
            var ret_ = this.c.n("animationDuration");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.c.v("animationDuration", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ProgressBase.prototype, "e", {
        get: function () {
            var ret_ = this.c.n("indeterminate");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.c.v("indeterminate", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ProgressBase.prototype, "d", {
        get: function () {
            var ret_ = this.c.n("hideLabel");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.c.v("hideLabel", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ProgressBase.prototype, "k", {
        get: function () {
            var ret_ = this.c.n("labelFormat");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.c.v("labelFormat", value_);
        },
        enumerable: false,
        configurable: true
    });
    ProgressBase.prototype.l = function () {
        this.nativeElement.connectedCallback();
    };
    ProgressBase.$t = markType(ProgressBase, 'ProgressBase', BaseElement.$);
    return ProgressBase;
}(BaseElement));
export { ProgressBase };
